@@ -32,6 +32,8 @@
 
 #include <kdebug.h>
 #include <kdialog.h>
+#include <kicon.h>
+#include <KIconLoader>
 #include <klocale.h>
 #include <kvbox.h>
 
@@ -60,7 +62,7 @@ void DialogViewConfigurationItem::refreshItem()
 {
   setFlags((flags() | Qt::ItemIsDragEnabled) &  ~Qt::ItemIsDropEnabled);
   setText(_name);
-  setIcon(KIconLoader::global()->loadIcon( _iconName, KIconLoader::Small, KIconLoader::SizeSmallMedium ) );
+  setIcon(KIconLoader::global()->loadIcon( _iconName, KIconLoader::Small, IconSize(KIconLoader::Toolbar) ));
   setData(Qt::ToolTipRole, _id);  // a hack. I am giving up to do it right
   setData(Qt::DisplayRole, _name);
 }
@@ -392,7 +394,8 @@ void DialogViewConfiguration::apply()
    {
        if ( pctl->isMandatory() ) {
            ProfControl* newCtl = new ProfControl(*pctl);
-           newCtl->show = "full"; // The user has selected controls => mandatory controls are now only necessary in extended or full mode
+           // The user has selected controls => mandatory controls (RegExp templates) should not been shown any longer
+           newCtl->setVisible(GuiVisibility::GuiNEVER);
            newControlset.push_back(newCtl);
        }
    }
