@@ -60,11 +60,15 @@ KMixPrefDlg::KMixPrefDlg(QWidget *parent, GlobalConfig& config) :
 {
 	setFaceType(KPageDialog::List);
 	//setCaption(i18n("Configure"));
+
+#ifndef X_KMIX_KF5_BUILD
 	setButtons(Ok | Cancel | Apply);
 
 	setDefaultButton(Ok);
+#endif
 
 	dvc = 0;
+	dvcSpacerBelow = 0;
 
 	// general buttons
 	m_generalTab = new QFrame(this);
@@ -76,7 +80,9 @@ KMixPrefDlg::KMixPrefDlg(QWidget *parent, GlobalConfig& config) :
 	createControlsTab();
 	updateWidgets(); // I thought KConfigDialog would call this, but I saw during a gdb session that it does not do so.
 
+#ifndef X_KMIX_KF5_BUILD
 	showButtonSeparator(true);
+#endif
 
 	generalPage = addPage(m_generalTab, i18n("General"), "configure");
 	startupPage = addPage(m_startupTab, i18n("Start"), "preferences-system-login");
@@ -115,7 +121,7 @@ void KMixPrefDlg::switchToPage(KMixPrefPage page)
 // --- TABS --------------------------------------------------------------------------------------------------
 void KMixPrefDlg::createStartupTab()
 {
-	QBoxLayout* layoutStartupTab = new QVBoxLayout(m_startupTab);
+	layoutStartupTab = new QVBoxLayout(m_startupTab);
 	layoutStartupTab->setMargin(0);
 	layoutStartupTab->setSpacing(KDialog::spacingHint());
 
@@ -134,10 +140,7 @@ void KMixPrefDlg::createStartupTab()
 	addWidgetToLayout(allowAutostart, layoutStartupTab, 10,
 		i18n("Enables the KMix autostart service (kmix_autostart.desktop)"), "AutoStart");
 
-
-	allowAutostartWarning = new QLabel(
-		i18n("Autostart can not be enabled, as the autostart file kmix_autostart.desktop is not installed."),
-		m_startupTab);
+    allowAutostartWarning = new QLabel("",	m_startupTab); // actual text is added later
 	addWidgetToLayout(allowAutostartWarning, layoutStartupTab, 10, "", "");
 	layoutStartupTab->addStretch();
 }
@@ -165,18 +168,25 @@ void KMixPrefDlg::createOrientationGroup(const QString& labelSliderOrientation,
 	}
 
 	// Add both buttons to button group
+	//qrbHor->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 	orientationGroup->addButton(qrbHor);
 	orientationGroup->addButton(qrbVert);
 	// Add both buttons and label to layout
-	orientationLayout->addWidget(qlb, row, 0);
-	orientationLayout->addWidget(qrbHor, row, 1);
-	orientationLayout->addWidget(qrbVert, row, 2);
+	orientationLayout->addWidget(qlb, row, 0, Qt::AlignLeft);
+	orientationLayout->addWidget(qrbHor, row, 1, Qt::AlignLeft);
+	orientationLayout->addWidget(qrbVert, row, 2, Qt::AlignLeft);
+	orientationLayout->addItem(new QSpacerItem(1,1,QSizePolicy::Expanding), row, 3);
 
 	connect(qrbHor, SIGNAL(toggled(bool)), SLOT(updateButtons()));
 	connect(qrbVert, SIGNAL(toggled(bool)), SLOT(updateButtons()));
 
+#ifdef X_KMIX_KF5_BUILD
+    connect(button(QDialogButtonBox::Apply), SIGNAL(clicked()), SLOT(kmixConfigHasChangedEmitter()));
+    connect(button(QDialogButtonBox::Ok), SIGNAL(clicked()), SLOT(kmixConfigHasChangedEmitter()));
+#else
 	connect(this, SIGNAL(applyClicked()), SLOT(kmixConfigHasChangedEmitter()));
 	connect(this, SIGNAL(okClicked()), SLOT(kmixConfigHasChangedEmitter()));
+#endif
 
 //	connect(qrbHor, SIGNAL(toggled(bool)), SLOT(settingsChangedSlot()));
 //	connect(qrbVert, SIGNAL(toggled(bool)), SLOT(settingsChangedSlot()));
@@ -226,13 +236,11 @@ void KMixPrefDlg::createGeneralTab()
 
 	// [CONFIG] Slider orientation (main window)
 	QGridLayout* orientationGrid = new QGridLayout();
+	orientationGrid->setHorizontalSpacing(KDialog::spacingHint());
 	layout->addItem(orientationGrid);
 
+	// Slider orientation (main window, and tray popup separately).
 	createOrientationGroup(i18n("Slider orientation: "), orientationGrid, 0, KMixPrefDlg::MainOrientation);
-
-	// Slider orientation (tray popup). We use an extra setting
-	QBoxLayout* orientation2Layout = new QHBoxLayout();
-	layout->addItem(orientation2Layout);
 	createOrientationGroup(i18n("Slider orientation (System tray volume control):"), orientationGrid, 1, KMixPrefDlg::TrayOrientation);
 
 	// Push everything above to the top
@@ -390,16 +398,36 @@ void KMixPrefDlg::showEvent(QShowEvent * event)
 	m_volumeOverdrive->setVisible(overdriveAvailable);
 	volumeOverdriveWarning->setVisible(overdriveAvailable);
 
-	QString autostartConfigFilename = KGlobal::dirs()->findResource("autostart", QString("kmix_autostart.desktop"));
-	kDebug()
-	<< "autostartConfigFilename = " << autostartConfigFilename;
+    QString autostartConfigFilename = KGlobal::dirs()->findResource(
+                                      #ifdef X_KMIX_KF5_BUILD
+                                          "xdgconf-autostart",
+                                      #else
+                                          "autostart",
+                                      #endif
+                                          QString("kmix_autostart.desktop"));
+    kDebug() << "autostartConfigFilename = " << autostartConfigFilename;
 	bool autostartFileExists = !autostartConfigFilename.isNull();
 
 	//allowAutostartWarning->setEnabled(autostartFileExists);
-	allowAutostartWarning->setVisible(!autostartFileExists);
+	if (!autostartFileExists)
+	{
+		if (allowAutostartWarning->text().isEmpty())
+		{
+			// Text is set here, as it is very long and would force the dialog to be very wide, even when
+			// the allowAutostartWarning would not be visible.
+			allowAutostartWarning->setText(
+					i18n("Autostart can not be enabled, as the autostart file kmix_autostart.desktop is not installed."));
+		}
+		allowAutostartWarning->setVisible(!autostartFileExists);
+		allowAutostartWarning->setEnabled(false); // always just a grayed out note
+	}
 	allowAutostart->setEnabled(autostartFileExists);
 
+#ifdef X_KMIX_KF5_BUILD
+	KConfigDialog::showEvent(event);
+#else
 	KDialog::showEvent(event);
+#endif
 }
 
 
@@ -409,6 +437,8 @@ void KMixPrefDlg::replaceBackendsInTab()
 	{
 		layoutControlsTab->removeWidget(dvc);
 		delete dvc;
+		layoutControlsTab->removeItem(dvcSpacerBelow);
+		delete dvcSpacerBelow;
 	}
 
 	QSet<QString> backendsFromConfig = GlobalConfig::instance().getMixersForSoundmenu();
@@ -419,7 +449,10 @@ void KMixPrefDlg::replaceBackendsInTab()
 	layoutControlsTab->addWidget(dvc);
 
 	// Push everything above to the top
-	layoutControlsTab->addStretch();
+//	layoutControlsTab->addStretch();
+
+	dvcSpacerBelow = new QSpacerItem(1,1);
+	layoutControlsTab->addItem(dvcSpacerBelow);
 }
 
 
